==> buildfile_1.0.0_for_3.0_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/editors/BuildFileDesignerEditor.java <==
/*
 * 2004-10-22 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.editors;

import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.resources.IResourceChangeListener;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.IFileEditorInput;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.editors.text.TextEditor;
import org.eclipse.ui.ide.IDE;
import org.eclipse.ui.part.FileEditorInput;
import org.eclipse.ui.part.MultiPageEditorPart;
import org.jdom.Document;
import org.vivianj.eclipse.plugin.buildfile.group.RightGroup;
import org.vivianj.eclipse.plugin.buildfile.listener.ProjectTreeMouseListener;
import org.vivianj.eclipse.plugin.buildfile.listener.ProjectTreeSelectionListener;
import org.vivianj.eclipse.plugin.buildfile.util.BuildFileContent;
import org.vivianj.eclipse.plugin.buildfile.util.BuildFileTree;
import org.vivianj.eclipse.plugin.buildfile.util.ControlDispose;
import org.vivianj.eclipse.plugin.buildfile.util.GroupFactory;
import org.vivianj.eclipse.plugin.buildfile.util.Resource;

/**
 * JUnitDesignerEditor ʵֶant buildfileGUI 
 */
public class BuildFileDesignerEditor extends MultiPageEditorPart implements
		IResourceChangeListener {

	/** buildfilesource view */
	public TextEditor editor;

	/** ӦݵJDom document */
	public Document document = null;

	/** documentɵ */
	public Tree tree = null;

	/** ѡеĽڵ */
	private TreeItem selected = null;

	public static int i = 0;

	/** ұߵϸϢʾ */
	public Group rightGroup = null;

	/** ߵʾ */
	public Group leftGroup = null;

	public Composite page1Composite = null;

	/**
	 * buildfile༭Ķҳview design view  source view
	 */
	public BuildFileDesignerEditor() {
		super();
		ResourcesPlugin.getWorkspace().addResourceChangeListener(this);
	}

	/**
	 * source view
	 */
	void createPage0() {
		try {
			editor = new TextEditor();

			int index = addPage(editor, getEditorInput());
			setPageText(index, editor.getTitle());
		} catch (PartInitException e) {
			ErrorDialog.openError(getSite().getShell(),
					"Error creating nested text editor", null, e.getStatus());
		}
	}

	/**
	 *  design view
	 */
	void createPage1() {
		page1Composite = new Composite(getContainer(), SWT.NONE);
		int index = addPage(page1Composite);
		setPageText(index, Resource.getSource("page1.title"));
	}

	/**
	 * ҳ
	 */
	protected void createPages() {
		createPage1();
		createPage0();
		
		this.createDesignView(this.page1Composite);
	}

	public void dispose() {
		ResourcesPlugin.getWorkspace().removeResourceChangeListener(this);
		super.dispose();
	}

	/**
	 * doSave ĵ
	 */
	public void doSave(IProgressMonitor monitor) {
		getEditor(1).doSave(monitor);
	}

	/**
	 * doSaveAsʵļ "Ϊ" 
	 */
	public void doSaveAs() {
		IEditorPart editor = getEditor(1);
		editor.doSaveAs();
		setPageText(1, editor.getTitle());
		setInput(editor.getEditorInput());
	}

	public void gotoMarker(IMarker marker) {
		setActivePage(1);
		IDE.gotoMarker(getEditor(1), marker);
	}

	public void init(IEditorSite site, IEditorInput editorInput)
			throws PartInitException {
		if (!(editorInput instanceof IFileEditorInput))
			throw new PartInitException(
					"Invalid Input: Must be IFileEditorInput");
		super.init(site, editorInput);
	}

	public boolean isSaveAsAllowed() {
		return true;
	}

	/**
	 * ҳ֮תĴ
	 */
	protected void pageChange(int newPageIndex) {
		super.pageChange(newPageIndex);
		if (newPageIndex == 0) {
			this.createDesignView(this.page1Composite);
		} else if (newPageIndex == 1) {
			BuildFileContent buildFileContent = new BuildFileContent();
			buildFileContent.setTree(this.tree);
			buildFileContent.setEditor(editor);
			buildFileContent.refreshContent();
		}
	}

	/**
	 * رձ༭ʱرview
	 */
	public void resourceChanged(final IResourceChangeEvent event) {
		if (event.getType() == IResourceChangeEvent.PRE_CLOSE) {
			Display.getDefault().asyncExec(new Runnable() {
				public void run() {
					IWorkbenchPage[] pages = getSite().getWorkbenchWindow()
							.getPages();
					for (int i = 0; i < pages.length; i++) {
						if (((FileEditorInput) editor.getEditorInput())
								.getFile().getProject().equals(
										event.getResource())) {
							IEditorPart editorPart = pages[i].findEditor(editor
									.getEditorInput());
							pages[i].closeEditor(editorPart, true);
						}
					}
				}
			});
		}
	}

	/**
	 * Design View Panel
	 *  
	 */
	private void createDesignView(Composite composite) {
		//ScrolledComposite composite = (ScrolledComposite) p_composite;
		ControlDispose.disposeControls(composite);
		//		ʾLayout
		GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 2;
		composite.setLayout(gridLayout);
		composite.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL
				| GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL
				| GridData.GRAB_VERTICAL));

		//һGroup,Ϊʾ
		leftGroup = new Group(composite, SWT.LEFT);
		//GroupLayout,ʾռ߲
		leftGroup.setLayout(new GridLayout());
		leftGroup.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL
				| GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL
				| GridData.GRAB_VERTICAL));
		//ʾʾϢ
		leftGroup.setText(Resource.getSource("project.tip"));

		//ݴ򿪵buildfile
		BuildFileTree buildFileTree = new BuildFileTree();
		buildFileTree.setGroup(leftGroup);
		buildFileTree.setTextEditor(editor);

		this.tree = buildFileTree.createTree();

		this.tree.setSelection(new TreeItem[] { this.tree.getTopItem() });

		//һGroup,ΪѡнڵϸϢʾ
		rightGroup = new Group(composite, SWT.NONE);
		
		TreeItem treeItem[] = this.tree.getSelection();
		int i = this.tree.getSelectionCount();
		if (i > 0) {
			TreeItem selection = treeItem[0];
			Object o = selection.getData();
			//µ
			RightGroup right = GroupFactory.getGroup(o, rightGroup,
					selection);
			right.createPanel(RightGroup.UPDATE);
		}

		//Ϊ
		this.tree.addSelectionListener(new ProjectTreeSelectionListener(tree,
				rightGroup,this.editor));
		this.tree.addMouseListener(new ProjectTreeMouseListener(rightGroup,this.editor));
		//ˢҳ沼
		composite.layout();
	}
}

==> buildfile_1.2.36_for_3.0_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/editors/BuildFileDesignerEditor.java <==
/*
 * 2004-10-22 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.editors;

import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.resources.IResourceChangeListener;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.IFileEditorInput;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.editors.text.TextEditor;
import org.eclipse.ui.ide.IDE;
import org.eclipse.ui.part.FileEditorInput;
import org.eclipse.ui.part.MultiPageEditorPart;
import org.jdom.Document;
import org.vivianj.eclipse.plugin.buildfile.group.PropertyGroup;
import org.vivianj.eclipse.plugin.buildfile.group.RightGroup;
import org.vivianj.eclipse.plugin.buildfile.listener.ProjectTreeMouseListener;
import org.vivianj.eclipse.plugin.buildfile.listener.ProjectTreeSelectionListener;
import org.vivianj.eclipse.plugin.buildfile.util.BuildFileContent;
import org.vivianj.eclipse.plugin.buildfile.util.BuildFileTree;
import org.vivianj.eclipse.plugin.buildfile.util.ControlDispose;
import org.vivianj.eclipse.plugin.buildfile.util.Resource;

/**
 * JUnitDesignerEditor ʵֶant buildfileGUI 
 */
public class BuildFileDesignerEditor extends MultiPageEditorPart implements
		IResourceChangeListener {

	/** buildfilesource view */
	public TextEditor editor;

	/** ӦݵJDom document */
	public Document document = null;

	/** documentɵ */
	public Tree tree = null;

	/** ѡеĽڵ */
	private TreeItem selected = null;

	public static int i = 0;

	/** ұߵϸϢʾ */
	public Group rightGroup = null;

	/** ߵʾ */
	public Group leftGroup = null;

	public Composite page1Composite = null;

	/**
	 * buildfile༭Ķҳview design view  source view
	 */
	public BuildFileDesignerEditor() {
		super();
		ResourcesPlugin.getWorkspace().addResourceChangeListener(this);
	}

	/**
	 * source view
	 */
	void createPage0() {
		try {
			editor = new TextEditor();

			int index = addPage(editor, getEditorInput());
			setPageText(index, editor.getTitle());
		} catch (PartInitException e) {
			ErrorDialog.openError(getSite().getShell(),
					"Error creating nested text editor", null, e.getStatus());
		}
	}

	/**
	 *  design view
	 */
	void createPage1() {
		page1Composite = new Composite(getContainer(), SWT.NONE);
		int index = addPage(page1Composite);
		setPageText(index, Resource.getSource("page1.title"));
	}

	/**
	 * ҳ
	 */
	protected void createPages() {
		createPage1();
		createPage0();
		this.setPartName(editor.getTitle());
		this.setContentDescription("author : bookman");
		this.createDesignView(this.page1Composite);
	}

	public void dispose() {
		ResourcesPlugin.getWorkspace().removeResourceChangeListener(this);
		super.dispose();
	}

	/**
	 * doSave ĵ
	 */
	public void doSave(IProgressMonitor monitor) {
		getEditor(1).doSave(monitor);
	}

	/**
	 * doSaveAsʵļ "Ϊ" 
	 */
	public void doSaveAs() {
		IEditorPart editor = getEditor(1);
		editor.doSaveAs();
		setPageText(1, editor.getTitle());
		setInput(editor.getEditorInput());
	}

	public void gotoMarker(IMarker marker) {
		setActivePage(1);
		IDE.gotoMarker(getEditor(1), marker);
	}

	public void init(IEditorSite site, IEditorInput editorInput)
			throws PartInitException {
		if (!(editorInput instanceof IFileEditorInput))
			throw new PartInitException(
					"Invalid Input: Must be IFileEditorInput");
		super.init(site, editorInput);
	}

	public boolean isSaveAsAllowed() {
		return true;
	}

	/**
	 * ҳ֮תĴ
	 */
	protected void pageChange(int newPageIndex) {
		super.pageChange(newPageIndex);
		if (newPageIndex == 0) {
			this.createDesignView(this.page1Composite);
		} else if (newPageIndex == 1) {
			BuildFileContent buildFileContent = new BuildFileContent();
			buildFileContent.setTree(this.tree);
			buildFileContent.setEditor(editor);
			buildFileContent.refreshContent();
		}
	}

	/**
	 * رձ༭ʱرview
	 */
	public void resourceChanged(final IResourceChangeEvent event) {
		if (event.getType() == IResourceChangeEvent.PRE_CLOSE) {
			Display.getDefault().asyncExec(new Runnable() {
				public void run() {
					IWorkbenchPage[] pages = getSite().getWorkbenchWindow()
							.getPages();
					for (int i = 0; i < pages.length; i++) {
						if (((FileEditorInput) editor.getEditorInput())
								.getFile().getProject().equals(
										event.getResource())) {
							IEditorPart editorPart = pages[i].findEditor(editor
									.getEditorInput());
							pages[i].closeEditor(editorPart, true);
						}
					}
				}
			});
		}
	}

	/**
	 * Design View Panel
	 *  
	 */
	private void createDesignView(Composite composite) {
		//ScrolledComposite composite = (ScrolledComposite) p_composite;
		ControlDispose.disposeControls(composite);
		//		ʾLayout
		GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 2;
		composite.setLayout(gridLayout);
		composite.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL
				| GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL
				| GridData.GRAB_VERTICAL));

		//һGroup,Ϊʾ
		leftGroup = new Group(composite, SWT.LEFT);
		//GroupLayout,ʾռ߲
		leftGroup.setLayout(new GridLayout());
		leftGroup.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL
				| GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL
				| GridData.GRAB_VERTICAL));
		//ʾʾϢ
		leftGroup.setText(Resource.getSource("project.tip"));

		//ݴ򿪵buildfile
		BuildFileTree buildFileTree = new BuildFileTree();
		buildFileTree.setGroup(leftGroup);
		buildFileTree.setTextEditor(editor);

		this.tree = buildFileTree.createTree();

		this.tree.setSelection(new TreeItem[] { this.tree.getTopItem() });
		TreeItem treeItem[] = this.tree.getSelection();
		
		//һGroup,ΪѡнڵϸϢʾ
		rightGroup = new Group(composite, SWT.NONE);

		
		int i = this.tree.getSelectionCount();
		if (i > 0) {
			TreeItem selection = treeItem[0];
			//µ
			RightGroup right = new PropertyGroup(rightGroup, selection);
			right.createPanel();
		}
		//Ϊ
		this.tree.addSelectionListener(new ProjectTreeSelectionListener(tree,
				rightGroup, this.editor));
		this.tree.addMouseListener(new ProjectTreeMouseListener(rightGroup,
				this.editor));
		//ˢҳ沼
		composite.layout();
	}
}
